/**
 * A utility class for performing conversions of various 
 * kinds
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class Converter
{
    // Constants
    public static final double MILES_PER_KILOMETER = 0.621371;
    public static final int    FEET_PER_MILE       = 5280;    


    /**
     * Convert from miles to kilometers
     *
     * @param  miles   The distance in mi
     * @return         The equivalent distance in km
     */
    public static double toKilometers(double miles)
    {
       return toKPH(miles);
    }

    /**
     * Convert from mi/hr to km/hr
     *
     * @param  mph     The speed in mi/hr
     * @return         The equivalent speed in km/hr
     */
    public static double toKPH(double mph)
    {
       // Note: This function is called by toKilometers() since
       // the conversions are the same. Hence, if for some reason
       // this function is changed, that function will also need
       // to be changed.
       double kph;
       
       kph = mph / MILES_PER_KILOMETER;       

       return kph;       
    }
    
    /**
     * Convert from feet to miles
     *
     * @param  feet    The distance in ft
     * @return         The equivalent distance in mi
     */
    public static double toMiles(int feet)
    {
       double    miles;
       
       miles = (double)feet / (double)FEET_PER_MILE;

       return miles;       
    }

    /**
     * Return the number of feet remaining after converting
     * the given number of feet to whole (i.e., truncated) miles
     *
     * @param  feet    The distance in ft
     * @return         The number of remaining feet
     */
    public static int toRemainingFeet(int feet)
    {
       int    remainder;
       
       remainder = feet % FEET_PER_MILE;
       
       return remainder;       
    }

    /**
     * Convert from feet to whole (i.e., truncated) miles
     *
     * @param  feet    The distance in ft
     * @return         The number of whole miles
     */
    public static int toWholeMiles(int feet)
    {
       int    wholeMiles;
       
       wholeMiles = feet / FEET_PER_MILE;
       
       return wholeMiles;       
    }
    
}
