import java.awt.*;
import java.awt.font.*;
import java.awt.geom.*;
import javax.swing.*;

/**
 * A Dashboard can be used to display the current speed, the trip
 * distance, and the average trip speed.
 *
 * Note: This is not a well-designed class. It is designed in such a way
 * that a single .class file can be given to introductory programming
 * students and they can use it with static method calls.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 2.0 (Analog)
 */
public class Dashboard extends JPanel
{
    private static Dashboard  instance = new Dashboard();
    
    private boolean           showTripDistance, showTripSpeed;
    private double            speed, tripKM, tripSpeedKPH, tripSpeedMPH;
    private Gauge             gauge;    
    private int               tripFeet, tripMiles;    
    private JFrame            frame;
    private JLabel            tripLabel, tripKMLabel, tripKPHLabel;
    private JLabel            tripMILabel, tripMPHLabel;    
    
    private final Color GOLD   = new Color(203,182,119);
    private final Color PURPLE = new Color( 69,  0,132);


    /**
     * Default Constructor
     */
    private Dashboard()
    {
       super();
       Font          large, small;       
       JPanel        contentPane;       
       String        lookAndFeel;       

       try 
       {
          lookAndFeel = UIManager.getSystemLookAndFeelClassName();
          UIManager.setLookAndFeel(lookAndFeel);
       }
       catch (Exception e)
       {
          // Use the default look and feel
       }

       frame = new JFrame();
       frame.setTitle("DukeDash");       
       frame.setSize(640,640);
       frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);       
       frame.setResizable(false);       
       contentPane = (JPanel)frame.getContentPane();
       contentPane.setBackground(Color.BLACK);       
       contentPane.setLayout(null);
       contentPane.add(this, BorderLayout.CENTER);
       setBackground(Color.BLACK);       

       speed  =   0.0;       

       showTripDistance     = false;
       showTripSpeed        = false;

       large = new Font("JACKIE", Font.PLAIN, 48);
       small = new Font(Font.SANS_SERIF, Font.PLAIN, 24);
       
       gauge = new Gauge(0.0, 150.0, Gauge.SEMI_CIRCLE);
       gauge.setBackground(Color.BLACK);
       gauge.setForeground(Color.WHITE);
       gauge.setHighlight(new Color( 69,  0,132));
       gauge.setFont(new Font(Font.SANS_SERIF, Font.BOLD, 14));
       gauge.setBounds(80,160,480,240);       
       contentPane.add(gauge);
       

       tripLabel = new JLabel();
       tripLabel.setFont(small);       
       tripLabel.setBounds(160,400, 320, 40);
       tripLabel.setBackground(Color.BLACK);
       tripLabel.setForeground(PURPLE);       
       tripLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripLabel);

       tripMPHLabel = new JLabel();
       tripMPHLabel.setFont(small);       
       tripMPHLabel.setBounds(160,440, 160, 40);
       tripMPHLabel.setBackground(Color.BLACK);
       tripMPHLabel.setForeground(Color.WHITE);       
       tripMPHLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripMPHLabel);

       tripKPHLabel = new JLabel();
       tripKPHLabel.setFont(small);       
       tripKPHLabel.setBounds(160,480, 160, 40);
       tripKPHLabel.setBackground(Color.BLACK);
       tripKPHLabel.setForeground(Color.WHITE);       
       tripKPHLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripKPHLabel);
       
       tripMILabel = new JLabel();
       tripMILabel.setFont(small);       
       tripMILabel.setBounds(320,440, 160, 40);
       tripMILabel.setBackground(Color.BLACK);
       tripMILabel.setForeground(Color.WHITE);       
       tripMILabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripMILabel);

       tripKMLabel = new JLabel();
       tripKMLabel.setFont(small);       
       tripKMLabel.setBounds(320,480, 160, 40);
       tripKMLabel.setBackground(Color.BLACK);
       tripKMLabel.setForeground(Color.WHITE);       
       tripKMLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripKMLabel);
    }


       
    /**
     * Repaint this component if it is visible
     */
    public void refresh()
    {
       if (!instance.frame.isVisible()) instance.frame.setVisible(true);       

       gauge.setValue(speed);       

       if (showTripDistance || showTripSpeed)
       {
          tripLabel.setText("Trip Information");          
       }
       

       if (showTripDistance)
       {
         tripMILabel.setText(String.format("%3d mi, %4d ft", 
                                           tripMiles, tripFeet));
         tripKMLabel.setText(String.format("%6.2f km", tripKM));
       }
       
       if (showTripSpeed)
       {
         tripMPHLabel.setText(String.format("%5.2f mi/hr", tripSpeedMPH));
         tripKPHLabel.setText(String.format("%5.2f km/hr", tripSpeedKPH));
       }
       
       repaint();

       // This will put the calling thread to sleep briefly
       // so that the attributes can be changed in a loop
       // and appear to be animated
       try
       {
          Thread.sleep(100);
       }
       catch (InterruptedException ie)
       {
          // Ignore
       }
    }
    

    /**
     * Set the current speed (in km/hr)
     *
     * @param kph   The current speed
     */
    public static void setSpeed(double kph)
    {
       instance.speed = kph;       

       instance.refresh();       
    }
    

    /**
     * Set the distance traveled on this trip in both kilometers
     * and miles,feet.  Note: This method does not check to ensure that
     * the two values are consistent
     *
     * @param km    The distance in kilometers
     * @param mile  The distance in whole miles
     * @param feet  The distance in "leftover" feet
     */
    public static void setTripDistance(double km, int miles, int feet)
    {
       instance.showTripDistance  = true;       
       instance.tripKM            = km;       
       instance.tripMiles         = miles;
       instance.tripFeet          = feet;       

       instance.refresh();       
    }
    


    /**
     * Set the average speed during this trip in both km/hr and
     * mi/hr. Note: This method does not check to ensure that
     * the two values are consistent
     *
     * @param kph   The average speed in kph
     * @param mph   The average speed in mph
     */
    public static void setTripSpeed(double kph, double mph)
    {
       instance.showTripSpeed = true;       
       instance.tripSpeedKPH  = kph;      
       instance.tripSpeedMPH  = mph;      

       instance.refresh();       
    }
}
