import java.awt.*;
import java.awt.font.*;
import java.awt.geom.*;
import javax.swing.*;

/**
 * A Dashboard can be used to display the current speed, the trip
 * distance, and the average trip speed.
 *
 * Note: This is not a well-designed class. It is designed in such a way
 * that a single .class file can be given to introductory programming
 * students.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 1.0 (Digital)
 */
public class Dashboard extends JFrame
{
    private boolean           showTripDistance, showTripSpeed;
    private double            speed, tripKM, tripSpeedKPH, tripSpeedMPH;
    private int               tripFeet, tripMiles;    
    private JLabel            speedLabel, tripLabel, tripKMLabel, tripKPHLabel;
    private JLabel            tripMILabel, tripMPHLabel;    
    
    private final Color GOLD   = new Color(203,182,119);
    private final Color PURPLE = new Color( 69,  0,132);


    /**
     * Default Constructor
     */
    public Dashboard()
    {
       super();
       Font          large, small;       
       JPanel        contentPane;       
       String        lookAndFeel;       

       try 
       {
          lookAndFeel = UIManager.getSystemLookAndFeelClassName();
          UIManager.setLookAndFeel(lookAndFeel);
       }
       catch (Exception e)
       {
          // Use the default look and feel
       }

       setTitle("DukeDash");       
       setSize(640,640);
       setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);       
       setResizable(false);       
       contentPane = (JPanel)getContentPane();
       contentPane.setBackground(Color.BLACK);       
       contentPane.setLayout(null);
       contentPane.setBackground(Color.BLACK);       

       speed  =   0.0;       

       showTripDistance     = false;
       showTripSpeed        = false;

       large = new Font("JACKIE", Font.PLAIN, 48);
       small = new Font(Font.SANS_SERIF, Font.PLAIN, 24);
       
       speedLabel = new JLabel();
       speedLabel.setFont(large);       
       speedLabel.setBounds(160,160,320,160);       
       speedLabel.setBackground(Color.BLACK);
       speedLabel.setForeground(Color.WHITE);       
       speedLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(speedLabel);

       tripLabel = new JLabel();
       tripLabel.setFont(small);       
       tripLabel.setBounds(160,400, 320, 40);
       tripLabel.setBackground(Color.BLACK);
       tripLabel.setForeground(PURPLE);       
       tripLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripLabel);

       tripMPHLabel = new JLabel();
       tripMPHLabel.setFont(small);       
       tripMPHLabel.setBounds(160,440, 160, 40);
       tripMPHLabel.setBackground(Color.BLACK);
       tripMPHLabel.setForeground(Color.WHITE);       
       tripMPHLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripMPHLabel);

       tripKPHLabel = new JLabel();
       tripKPHLabel.setFont(small);       
       tripKPHLabel.setBounds(160,480, 160, 40);
       tripKPHLabel.setBackground(Color.BLACK);
       tripKPHLabel.setForeground(Color.WHITE);       
       tripKPHLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripKPHLabel);
       
       tripMILabel = new JLabel();
       tripMILabel.setFont(small);       
       tripMILabel.setBounds(320,440, 160, 40);
       tripMILabel.setBackground(Color.BLACK);
       tripMILabel.setForeground(Color.WHITE);       
       tripMILabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripMILabel);

       tripKMLabel = new JLabel();
       tripKMLabel.setFont(small);       
       tripKMLabel.setBounds(320,480, 160, 40);
       tripKMLabel.setBackground(Color.BLACK);
       tripKMLabel.setForeground(Color.WHITE);       
       tripKMLabel.setHorizontalAlignment(SwingConstants.CENTER);       
       contentPane.add(tripKMLabel);

       setVisible(true);       
    }


       
    /**
     * Repaint this component if it is visible
     */
    public void refresh()
    {
       speedLabel.setText(String.format("%5.1f km/hr", speed));       

       if (showTripDistance || showTripSpeed)
       {
          tripLabel.setText("Trip Information");          
       }
       
       if (showTripDistance)
       {
         tripMILabel.setText(String.format("%3d mi, %4d ft", 
                                           tripMiles, tripFeet));
         tripKMLabel.setText(String.format("%6.2f km", tripKM));
       }
       
       if (showTripSpeed)
       {
         tripMPHLabel.setText(String.format("%5.2f mi/hr", tripSpeedMPH));
         tripKPHLabel.setText(String.format("%5.2f km/hr", tripSpeedKPH));
       }
       
       // This will put the calling thread to sleep briefly
       // so that the attributes can be changed in a loop
       // and appear to be animated
       try
       {
          Thread.sleep(100);
       }
       catch (InterruptedException ie)
       {
          // Ignore
       }
    }
    

    /**
     * Set the current speed (in km/hr)
     *
     * @param kph   The current speed
     */
    public void setSpeed(double kph)
    {
       speed = kph;       

       refresh();       
    }
    

    /**
     * Set the distance traveled on this trip in both kilometers
     * and miles,feet.  Note: This method does not check to ensure that
     * the two values are consistent
     *
     * @param km    The distance in kilometers
     * @param mile  The distance in whole miles
     * @param feet  The distance in "leftover" feet
     */
    public void setTripDistance(double km, int miles, int feet)
    {
       showTripDistance  = true;       
       tripKM            = km;       
       tripMiles         = miles;
       tripFeet          = feet;       

       refresh();       
    }
    


    /**
     * Set the average speed during this trip in both km/hr and
     * mi/hr. Note: This method does not check to ensure that
     * the two values are consistent
     *
     * @param kph   The average speed in kph
     * @param mph   The average speed in mph
     */
    public void setTripSpeed(double kph, double mph)
    {
       showTripSpeed = true;       
       tripSpeedKPH  = kph;      
       tripSpeedMPH  = mph;      

       refresh();       
    }
}
