/**
 * DetailedTripSetter is part of the prototype for DukeDash.
 *
 * It is passed String representations of the current speed in mi/hr,
 * the trip length in ft, and the trip duration in hr.
 *
 * It calculates the current speed in mi/hr, and the trip speed in
 * mi/hr and km/hr.
 *
 * Finally it displays this information on the Dashboard.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class DetailedTripSetter
{
    /**
     * The entry-point of the application.
     *
     * args[0] contains the current speed in mi/hr
     * args[1] contains the trip distance in ft
     * args[2] contains the trip duration in hr
     *
     * @param args  The command-line arguments (as discussed above)
     */
    public static void main(String[] args)
    {
       Dashboard      dashboard;       
       double         currentKPH, currentMPH;
       double         tripHours, tripKPH, tripMiles, tripMPH;
       int            tripFeet;
       

       // Convert the command-line arguments to numbers
       currentMPH = Double.parseDouble(args[0]);
       tripFeet   = Integer.parseInt(args[1]);       
       tripHours  = Double.parseDouble(args[2]);
       
       // Convert the current speed from mi/hr to km/hr
       currentKPH = Converter.toKPH(currentMPH);

       // Calculate the trip speed (in mi/hr and km/hr)
       tripMiles  = Converter.toMiles(tripFeet);
       tripMPH    = tripMiles / tripHours;       
       tripKPH    = Converter.toKPH(tripMPH);

       // Construct the Dashboard
       dashboard = new Dashboard();       

       // Display the current information
       dashboard.setSpeed(currentKPH);   

       // Display the trip information
       dashboard.setTripSpeed(tripKPH, tripMPH);
       dashboard.setTripDistance(Converter.toKilometers(tripMiles),
                                 Converter.toWholeMiles(tripFeet),
                                 Converter.toRemainingFeet(tripFeet));
    }
    
}
