import java.awt.*;
import javax.swing.*;

/**
 * A frame that contains a component that displays information about
 * temperatures on a map
 *
 * @author  Prof. David Bernstein, James Madison University
 * @version 1.0
 */
public class Map extends JFrame
{
    private MapComponent      mapComponent;


    /**
     * Explicit Value Constructor
     *
     * @param region   The name of the region (e.g., "va")
     */
    public Map(String region)
    {
       super();
       JPanel        contentPane;       
       String        lookAndFeel;
       

       try 
       {
          lookAndFeel = UIManager.getSystemLookAndFeelClassName();
          UIManager.setLookAndFeel(lookAndFeel);
       }
       catch (Exception e)
       {
          // Use the default look and feel
       }

       setTitle("WeatherBits");       
       setSize(800, 400);
       setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);       
       setResizable(false);       

       contentPane = (JPanel)getContentPane();
       contentPane.setLayout(null);

       mapComponent = new MapComponent(region);
       mapComponent.setBounds(0,0,800,600);
       mapComponent.setBackground(contentPane.getBackground());       
       contentPane.add(mapComponent);

       setVisible(true);       
    }


    /**
     * Set the temperature for a particular station
     *
     * @param icao4        The 4-letter ICAO code for the station
     * @param temperature  The temperature
     */
    public void setTemperature(String icao4, double temperature)
    {
       mapComponent.setTemperature(icao4, temperature);
    }
}
